@@ -5,7 +5,7 @@ use Carp;
 use base qw( Search::Tools::Object );
 use Search::Tools;    # XS required
 
-our $VERSION = '0.63';
+our $VERSION = '0.64';
 
 =pod
 
@@ -89,8 +89,8 @@ my @white_hex_pts = qw(
     2029
     202f
     205f
+    2060
     3000
-    feff
 );
 
 my @whitesp = ( '\s', '&nbsp;' );
@@ -632,9 +632,9 @@ sub unescape_named {
     if ( defined($t) ) {
 
         # named entities - check first to see if it is worth looping
-        if ( $t =~ m/&[a-zA-Z]+;/ ) {
+        if ( $t =~ m/&[a-zA-Z0-9]+;/ ) {
             for ( keys %HTML_ents ) {
-                if ( my $n = $t =~ s/&$_;/chr($HTML_ents{$_})/eg ) {
+                if ( my $n = $t =~ s/&$_;/chr($HTML_ents{$_})/egi ) {
 
                     #warn "replaced $_ -> $HTML_ents{$_} $n times in text";
                 }
